Crate type_dispatch

Crate type_dispatch 

Utilities for dispatching based on generic types.

Macros

dispatch_const
Dispatches a constant based on a given generic type.
dispatch_fn
Dispatches a function body based on a given generic type.
dispatch_impl
A function-like variant of impl_dispatch.
dispatch_type
Dispatches a constant based on a given generic type.

Traits

Dispatch
A dispatch of an object.
DispatchConst
A dispatch of a constant.
DispatchFn
A dispatch of a static function.

Attribute Macros

impl_dispatch
Dispatches a trait implementation to a specified set of generic types.